#!/bin/sh

#######################################################
# FileName:      10005_printk_buf_redirectTest.sh
# Description:   Printk buffer redirect function of the service node.
# Return:         0: function working ok.
# Return:         1: not enable
#
# Date:          2018-04-27
#######################################################
CHECK_ID=$(echo $(basename "$0") | awk -F "_" '{print $1}')
CHECK_DESC="Printk buffer redirect function of the service node."
# import log function, $1 is log level default is 2, $2 is check item id

CONFIG_FILE="/etc/log_redirect/config"
BIN_FILE="/usr/sbin/redirect_printk_buf"
source /usr/libexec/osHealthCheck/modules/logger.sh 2 $$ $savefile
[ -f "$CONFIG_FILE" ] && source "$CONFIG_FILE"

# Check redirect service file
if [ ! -f "$BIN_FILE" ]; then
    g_LOG_Warn "$BIN_FILE is missing, Check whether printk_buf_dev-kmod is installed!"
    CHECK_INFO="The redirect function of the service node is not install, but it is not a must."
    g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "OK" "${CHECK_INFO}"
    exit ${NORMAL}
fi

# Check redirect service status.
systemctl status redirect > /dev/null 2>&1
run=$?

if [ ${run} -ne 0 ]; then
    if [ -n "${start_paddr}" -o -n "${pci_bus_id}" ]; then
        g_LOG_Warn "redirect is configured, but not working!"
        CHECK_INFO="The printk buffer redirect function enable, but not working."
        g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "Abnormal" "${CHECK_INFO}"
        exit ${ABNORMAL}
    else
        g_LOG_Warn "redirect is not running, Check whether it is need enable!"
        CHECK_INFO="The printk buffer redirect function of the service node is not configured, but it is not a must."
        g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "OK" "${CHECK_INFO}"
        exit ${NORMAL}
    fi
fi

CHECK_INFO="The printk buffer redirect function of the service node is working."
g_LOG_Info "$CHECK_INFO"
g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "OK" "${CHECK_INFO}"
exit ${NORMAL}
