#!/bin/sh

#######################################################
# FileName:      10006_check_service_timeout.sh
# Description:   Check timeout of services.
# Return:         0: function working ok.
# Return:         1: not enable
#
# Date:          2018-06-05
#######################################################
CHECK_ID=$(echo $(basename "$0") | awk -F "_" '{print $1}')
CHECK_DESC="Check timeout of services."

ETC="/etc/systemd/system"
SYSTEM="/usr/lib/systemd/system"
DRACUT="/usr/lib/dracut/modules.d"
RUNTIME="/run/systemd"

source /usr/libexec/osHealthCheck/modules/logger.sh 2 $$ $savefile

flag=0
count=0
function read_dir(){
        for file in `find $1 -name "*.service"`
        do
                if [ ! -L $file -a -f $file ]; then
			grep -i "timeout" $file |grep -i "=0" 1>/dev/null 2>&1
                        if [ $? -eq 0 ]; then
                                flag=1
                                count=$((count + 1))
                                g_LOG_Warn $file" not configured timeout !"
                        fi
                fi
        done
}

# Check service file
if [ -d $ETC ]; then
	read_dir $ETC
fi

if [ -d $DRACUT ]; then
	read_dir $DRACUT
fi

if [ -d $RUNTIME ]; then
	read_dir $RUNTIME
fi

if [ -d $SYSTEM ]; then
	read_dir $SYSTEM
fi

if [ $flag == 0 ]; then
        CHECK_INFO="All services are configured timeout."
        g_LOG_Info "$CHECK_INFO"
        g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "OK" "${CHECK_INFO}"
        exit ${NORMAL}
else
        CHECK_INFO=$count" services are not configured timeout."
        g_LOG_Save_Result ${CHECK_ID} "${CHECK_DESC}" "Abnormal" "${CHECK_INFO}"
        exit ${ABNORMAL}
fi

